@@ -11,29 +11,32 @@
  A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License along with
- TALER; see the file COPYING.  If not, If not, see <http://www.gnu.org/licenses/>
+ TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
 
 /**
  * Entry point for the background page.
- * 
+ *
  * @author Florian Dold
  */
 
 "use strict";
 
-// TypeScript does not allow ".js" extensions in the
-// module name, so SystemJS must add it.
-System.config({
-                defaultJSExtensions: true,
-              });
+window.addEventListener("load", () => {
 
+  // TypeScript does not allow ".js" extensions in the
+  // module name, so SystemJS must add it.
+  System.config({
+                 defaultJSExtensions: true,
+                });
 
-System.import("../lib/wallet/wxMessaging")
-      .then((wxMessaging) => {
-        wxMessaging.wxMain();
-      })
-      .catch((e) => {
-        console.log("wallet failed");
-        console.error(e.stack);
-      });
+  System.import("../lib/wallet/wxMessaging")
+    .then((wxMessaging) => {
+      // Export as global for debugger
+      (window as any).wxMessaging = wxMessaging;
+      wxMessaging.wxMain();
+    }).catch((e) => {
+      console.log("wallet failed");
+      console.error(e.stack);
+    });
+});
